"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var types = require("tns-core-modules/utils/types");
var view_1 = require("tns-core-modules/ui/core/view");
var frame_1 = require("tns-core-modules/ui/frame");
var app = require("tns-core-modules/application");
var imageSource = require("tns-core-modules/image-source");
global.moduleMerge(common, exports);
function useAndroidX() {
    return global.androidx && global.androidx.core && global.androidx.core.graphics;
}
var DrawableResourcesNamespace = useAndroidX() ? androidx.core.graphics.drawable : android.support.v4.graphics.drawable;
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        return _super.call(this) || this;
    }
    ImageCacheIt.prototype.hasBorderWidth = function () {
        return this.borderTopWidth !== 0
            || this.borderRightWidth !== 0
            || this.borderBottomWidth !== 0
            || this.borderLeftWidth !== 0;
    };
    ImageCacheIt.prototype.hasBorderColor = function () {
        return !!this.borderTopColor || !!this.borderRightColor || !!this.borderBottomColor || !!this.borderLeftColor;
    };
    ImageCacheIt.prototype.hasUniformBorderColor = function () {
        return view_1.Color.equals(this.borderTopColor, this.borderRightColor) &&
            view_1.Color.equals(this.borderTopColor, this.borderBottomColor) &&
            view_1.Color.equals(this.borderTopColor, this.borderLeftColor);
    };
    ImageCacheIt.prototype.hasUniformBorderWidth = function () {
        return this.borderTopWidth === this.borderRightWidth &&
            this.borderTopWidth === this.borderBottomWidth &&
            this.borderTopWidth === this.borderLeftWidth;
    };
    ImageCacheIt.prototype.hasBorderRadius = function () {
        return this.borderTopLeftRadius > 0
            || this.borderTopRightRadius > 0
            || this.borderBottomRightRadius > 0
            || this.borderBottomLeftRadius > 0;
    };
    ImageCacheIt.prototype.hasUniformBorderRadius = function () {
        return this.borderTopLeftRadius === this.borderTopRightRadius &&
            this.borderTopLeftRadius === this.borderBottomRightRadius &&
            this.borderTopLeftRadius === this.borderBottomLeftRadius;
    };
    ImageCacheIt.prototype.hasUniformBorder = function () {
        return this.hasUniformBorderColor() &&
            this.hasUniformBorderWidth() &&
            this.hasUniformBorderRadius();
    };
    ImageCacheIt.prototype.getContext = function () {
        var context;
        if (frame_1.topmost()) {
            if (frame_1.topmost().android && frame_1.topmost().android.activity) {
                context = frame_1.topmost().android.activity;
            }
            else if (frame_1.topmost().currentPage && frame_1.topmost().currentPage.frame && frame_1.topmost().currentPage.frame.android && frame_1.topmost().currentPage.frame.android.activity) {
                context = frame_1.topmost().currentPage.frame.android.activity;
            }
        }
        if (!context) {
            context = this._context;
        }
        if (!context) {
            context = app.android.foregroundActivity || app.android.startActivity;
        }
        return context;
    };
    ImageCacheIt.prototype.getGlide = function () {
        if (!this._manager) {
            var ref_1 = new WeakRef(this);
            this._manager = com.bumptech.glide.Glide.with(this.getContext());
            this._manager.addDefaultRequestListener(new com.bumptech.glide.request.RequestListener({
                onLoadFailed: function (param0, param1, param2, param3) {
                    var owner = ref_1.get();
                    if (owner) {
                        owner.notify({
                            eventName: 'image:failed',
                            object: owner,
                            error: param0.getMessage()
                        });
                    }
                    return false;
                },
                onResourceReady: function (param0, param1, param2, param3, param4) {
                    var owner = ref_1.get();
                    if (owner) {
                        owner.notify({
                            eventName: 'image:loaded',
                            object: owner
                        });
                    }
                    return false;
                }
            }));
        }
        return this._manager;
    };
    ImageCacheIt.prototype.getErrorGlide = function () {
        if (!this._errorManager) {
            this._errorManager = com.bumptech.glide.Glide.with(this.getContext());
        }
        return this._errorManager;
    };
    ImageCacheIt.prototype.createNativeView = function () {
        return new android.widget.ImageView(this._context);
    };
    ImageCacheIt.prototype.initNativeView = function () {
        if (this.src) {
            var image = ImageCacheIt.getImage(this.src);
            if (this._manager) {
                this._manager.clear(this.nativeView);
            }
            this._builder = this.getGlide().load(image);
        }
        this.resetImage();
        this.setPlaceHolder();
        this.setErrorHolder();
        if (this._builder) {
            this._builder.into(this.nativeView);
        }
    };
    ImageCacheIt.prototype.disposeNativeView = function () {
        if (this._manager) {
            this._manager.clear(this.nativeView);
        }
        _super.prototype.disposeNativeView.call(this);
    };
    ImageCacheIt.prototype[view_1.borderTopColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderRightColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderBottomColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderLeftColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderTopWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderRightWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderBottomWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderLeftWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderTopLeftRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderTopRightRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderBottomLeftRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[view_1.borderBottomRightRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = null;
    };
    ImageCacheIt.prototype[image_cache_it_common_1.filterProperty.setNative] = function (filter) {
        this.filter = filter;
        this.resetImage(true);
    };
    ImageCacheIt.isNumber = function (value) {
        return typeof value === 'number';
    };
    ImageCacheIt.getResourceId = function (res) {
        if (res === void 0) { res = ''; }
        if (types.isString(res) && res.startsWith('res://')) {
            return utils.ad.resources.getDrawableId(res.replace('res://', ''));
        }
        return 0;
    };
    ImageCacheIt.prototype.calculateInSampleSize = function (options, reqWidth, reqHeight) {
        var height = options.outHeight;
        var width = options.outWidth;
        var inSampleSize = 1;
        if (height > reqHeight || width > reqWidth) {
            var halfHeight = height / 2;
            var halfWidth = width / 2;
            while ((halfHeight / inSampleSize) >= reqHeight
                && (halfWidth / inSampleSize) >= reqWidth) {
                inSampleSize *= 2;
            }
        }
        return inSampleSize;
    };
    ;
    ImageCacheIt.prototype.getResources = function () {
        if (!this._resources) {
            this._resources = this.getContext().getResources();
        }
        return this._resources;
    };
    ImageCacheIt.prototype.getDrawableWithBorder = function (source) {
        if (!source) {
            return null;
        }
        else {
            var image = void 0;
            var srcWidth = 0;
            var srcHeight = 0;
            var width = 0;
            var height = 0;
            var opts = new android.graphics.BitmapFactory.Options();
            if (types.isString(source)) {
                if (source.startsWith('res://')) {
                    var id = ImageCacheIt.getResourceId(source);
                    if (id) {
                        opts.inJustDecodeBounds = true;
                        android.graphics.BitmapFactory.decodeResource(this.getResources(), id, opts);
                        srcWidth = opts.outWidth;
                        srcHeight = opts.outHeight;
                        width = view_1.PercentLength.toDevicePixels(this.width, srcWidth);
                        height = view_1.PercentLength.toDevicePixels(this.height, srcHeight);
                        opts.inJustDecodeBounds = false;
                        opts.inScaled = true;
                        opts.inDensity = srcWidth;
                        opts.inTargetDensity = width;
                        opts.inSampleSize = this.calculateInSampleSize(opts, width, height);
                        opts.inTargetDensity = width * opts.inSampleSize;
                        image = android.graphics.BitmapFactory.decodeResource(this.getResources(), id, opts);
                    }
                }
                else {
                    var path = source;
                    if (source.startsWith('~/')) {
                        path = fs.path.join(fs.knownFolders.currentApp().path, source.replace('~/', ''));
                    }
                    else if (source.startsWith('file://')) {
                        path = source.replace('file://', '');
                    }
                    opts.inJustDecodeBounds = true;
                    android.graphics.BitmapFactory.decodeFile(path, opts);
                    srcWidth = opts.outWidth;
                    srcHeight = opts.outHeight;
                    width = view_1.PercentLength.toDevicePixels(this.width, srcWidth);
                    height = view_1.PercentLength.toDevicePixels(this.height, srcHeight);
                    opts.inJustDecodeBounds = false;
                    opts.inScaled = true;
                    opts.inDensity = srcWidth;
                    opts.inSampleSize = this.calculateInSampleSize(opts, width, height);
                    opts.inTargetDensity = width * opts.inSampleSize;
                    image = android.graphics.BitmapFactory.decodeFile(path, opts);
                }
            }
            else if (source instanceof imageSource.ImageSource) {
                image = source.android;
            }
            else if (source instanceof android.graphics.Bitmap) {
                image = source;
            }
            else if (source instanceof android.graphics.drawable.Drawable) {
                image = this.placeHolder.getBitmap();
            }
            if (image) {
                var left_right = view_1.layout.toDevicePixels(this.style.borderLeftWidth) + view_1.layout.toDevicePixels(this.style.borderRightWidth);
                left_right = left_right * 2 ? left_right : 0;
                var top_bottom = view_1.layout.toDevicePixels(this.style.borderTopWidth) + view_1.layout.toDevicePixels(this.style.borderBottomWidth);
                top_bottom = top_bottom ? top_bottom * 2 : 0;
                var pool = com.bumptech.glide.Glide.get(this.getContext()).getBitmapPool();
                var bitmap = pool.get(width, height, opts.inPreferredConfig || android.graphics.Bitmap.Config.ARGB_8888);
                var canvas = new android.graphics.Canvas(bitmap);
                var RectF = android.graphics.RectF;
                var paint = new android.graphics.Paint();
                paint.setAntiAlias(true);
                if (image.getWidth() !== width || image.getHeight() !== height) {
                    var new_holder = android.graphics.Bitmap.createScaledBitmap(image, width, height, true);
                    image = null;
                    image = new_holder;
                }
                var shader = new android.graphics.BitmapShader(image, android.graphics.Shader.TileMode.CLAMP, android.graphics.Shader.TileMode.CLAMP);
                paint.setShader(shader);
                if (this.hasUniformBorder() && this.hasBorderColor()) {
                    var borderWidth = view_1.layout.toDevicePixels(this.style.borderBottomWidth);
                    borderWidth = borderWidth ? borderWidth : 0;
                    var radius = view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius);
                    var path = new android.graphics.Path();
                    path.addRoundRect(new RectF(borderWidth, borderWidth, width - borderWidth, height - borderWidth), radius ? radius : 0, radius ? radius : 0, android.graphics.Path.Direction.CW);
                    var borderPaint = new android.graphics.Paint();
                    borderPaint.setAntiAlias(true);
                    borderPaint.setStyle(android.graphics.Paint.Style.STROKE);
                    borderPaint.setColor(this.style.borderRightColor && this.style.borderRightColor.android ? this.style.borderRightColor.android : android.graphics.Color.TRANSPARENT);
                    borderPaint.setStrokeWidth(borderWidth);
                    canvas.drawRoundRect(new RectF(borderWidth, borderWidth, width - borderWidth, height - borderWidth), radius, radius, paint);
                    if (borderWidth) {
                        canvas.drawPath(path, borderPaint);
                    }
                }
                else if (this.hasBorderColor()) {
                    var right = width;
                    var bottom = height;
                    var margin = 0;
                    var path = new android.graphics.Path();
                    var borderPaint = new android.graphics.Paint();
                    borderPaint.setStyle(android.graphics.Paint.Style.STROKE);
                    borderPaint.setColor(this.style.borderTopColor && this.style.borderTopColor.android ? this.style.borderTopColor.android : android.graphics.Color.TRANSPARENT);
                    var borderTopWidth = view_1.layout.toDevicePixels(this.style.borderTopWidth);
                    borderTopWidth = borderTopWidth ? borderTopWidth : 0;
                    borderPaint.setStrokeWidth(borderTopWidth);
                    path.moveTo(margin, 0);
                    path.lineTo(right, 0);
                    path.close();
                    if (borderTopWidth > 0) {
                        canvas.drawRect(new RectF(margin, margin, right, bottom), paint);
                        canvas.drawPath(path, borderPaint);
                    }
                    shader = new android.graphics.BitmapShader(bitmap, android.graphics.Shader.TileMode.CLAMP, android.graphics.Shader.TileMode.CLAMP);
                    paint.setShader(shader);
                    path.reset();
                    borderPaint.reset();
                    borderPaint.setStyle(android.graphics.Paint.Style.STROKE);
                    borderPaint.setColor(this.style.borderRightColor && this.style.borderRightColor.android ? this.style.borderRightColor.android : android.graphics.Color.TRANSPARENT);
                    var borderRightWidth = view_1.layout.toDevicePixels(this.style.borderRightWidth);
                    borderRightWidth = borderRightWidth ? borderRightWidth : 0;
                    borderPaint.setStrokeWidth(borderRightWidth);
                    path.moveTo(right, margin);
                    path.lineTo(right, bottom);
                    path.close();
                    if (borderRightWidth > 0) {
                        canvas.drawRect(new RectF(margin, margin, right, bottom), paint);
                        canvas.drawPath(path, borderPaint);
                    }
                    path.reset();
                    borderPaint.reset();
                    borderPaint.setStyle(android.graphics.Paint.Style.STROKE);
                    borderPaint.setColor(this.style.borderBottomColor && this.style.borderBottomColor.android ? this.style.borderBottomColor.android : android.graphics.Color.TRANSPARENT);
                    var borderBottomWidth = view_1.layout.toDevicePixels(this.style.borderBottomWidth);
                    borderBottomWidth = borderBottomWidth ? borderBottomWidth : 0;
                    borderPaint.setStrokeWidth(borderBottomWidth);
                    path.moveTo(right, bottom);
                    path.lineTo(0, bottom);
                    path.close();
                    if (borderBottomWidth > 0) {
                        canvas.drawRect(new RectF(margin, margin, right, bottom), paint);
                        canvas.drawPath(path, borderPaint);
                    }
                    path.reset();
                    borderPaint.reset();
                    borderPaint.setStyle(android.graphics.Paint.Style.STROKE);
                    borderPaint.setColor(this.style.borderLeftColor && this.style.borderLeftColor.android ? this.style.borderLeftColor.android : android.graphics.Color.TRANSPARENT);
                    var borderLeftWidth = view_1.layout.toDevicePixels(this.style.borderLeftWidth);
                    borderLeftWidth = borderLeftWidth ? borderLeftWidth : 0;
                    borderPaint.setStrokeWidth(borderLeftWidth);
                    path.moveTo(0, bottom);
                    path.lineTo(0, 0);
                    path.close();
                    if (borderLeftWidth > 0) {
                        canvas.drawRect(new RectF(0, 0, right, bottom), paint);
                        canvas.drawPath(path, borderPaint);
                    }
                }
                else {
                    var radius = view_1.layout.toDevicePixels(this.style.borderTopLeftRadius);
                    radius = radius ? radius : 0;
                    var diameter = radius * 2;
                    var margin = 0;
                    var right = width;
                    var bottom = height;
                    canvas.drawRoundRect(new RectF(0, 0, margin + diameter, margin + diameter), radius, radius, paint);
                    canvas.drawRect(new RectF(margin, margin + radius, margin + radius, bottom), paint);
                    canvas.drawRect(new RectF(margin + radius, margin, right, bottom), paint);
                    radius = view_1.layout.toDevicePixels(this.style.borderTopRightRadius);
                    radius = radius ? radius : 0;
                    diameter = radius * 2;
                    canvas.drawRoundRect(new RectF(right - diameter, margin, right, margin + diameter), radius, radius, paint);
                    canvas.drawRect(new RectF(margin, margin, right - radius, bottom), paint);
                    canvas.drawRect(new RectF(right - radius, margin + radius, right, bottom), paint);
                    radius = view_1.layout.toDevicePixels(this.style.borderBottomRightRadius);
                    radius = radius ? radius : 0;
                    diameter = radius * 2;
                    canvas.drawRoundRect(new RectF(margin, bottom - diameter, margin + diameter, bottom), radius, radius, paint);
                    canvas.drawRect(new RectF(margin, margin, margin + diameter, bottom - radius), paint);
                    canvas.drawRect(new RectF(margin + radius, margin, right, bottom), paint);
                    radius = view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius);
                    radius = radius ? radius : 0;
                    diameter = radius * 2;
                    canvas.drawRoundRect(new RectF(right - diameter, bottom - diameter, right, bottom), radius, radius, paint);
                    canvas.drawRect(new RectF(margin, margin, right - radius, bottom), paint);
                    canvas.drawRect(new RectF(right - radius, margin, right, bottom - radius), paint);
                }
                return new android.graphics.drawable.BitmapDrawable(this.getResources(), bitmap);
            }
            return null;
        }
    };
    ImageCacheIt.prototype.setPlaceHolder = function () {
        if (this.placeHolder) {
            var placeHolder = this.getDrawableWithBorder(this.placeHolder);
            if (placeHolder) {
                if (this._placeHolder) {
                    if (placeHolder.getBitmap().sameAs(this._placeHolder.getBitmap())) {
                        placeHolder.getBitmap().recycle();
                        utils.releaseNativeObject(placeHolder);
                        placeHolder = null;
                        return;
                    }
                    else {
                        this._placeHolder = null;
                    }
                }
                this._placeHolder = placeHolder;
                if (this._builder) {
                    this._builder.placeholder(this._placeHolder);
                }
            }
        }
    };
    ImageCacheIt.prototype.setErrorHolder = function () {
        if (this.errorHolder) {
            var errorHolder = this.getDrawableWithBorder(this._errorHolder);
            if (errorHolder) {
                if (this._errorHolder) {
                    if (errorHolder.getBitmap().sameAs(this._errorHolder.getBitmap())) {
                        errorHolder.getBitmap().recycle();
                        utils.releaseNativeObject(errorHolder);
                        errorHolder = null;
                        return;
                    }
                    else {
                        this._errorHolder = null;
                    }
                }
                this._errorHolder = errorHolder;
                if (this._builder) {
                    this._builder.error(this._errorHolder);
                }
            }
        }
    };
    ImageCacheIt.prototype[common.srcProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.srcProperty.setNative] = function (src) {
        var image = ImageCacheIt.getImage(src);
        if (!this._builder) {
            this._builder = this.getGlide().load(image);
        }
        else {
            this._builder.load(image);
        }
        this.resetImage();
        this.setPlaceHolder();
        this.setErrorHolder();
        this._builder.into(this.nativeView);
        return src;
    };
    ImageCacheIt.prototype[common.decodedWidthProperty.setNative] = function (width) {
        this.resetImage(true);
    };
    ImageCacheIt.prototype[common.decodedHeightProperty.setNative] = function (height) {
        this.resetImage(true);
    };
    ImageCacheIt.getImage = function (src) {
        var nativeImage;
        if (types.isNullOrUndefined(src)) {
            return src;
        }
        if (types.isString(src)) {
            if (src.substr(0, 1) === '/') {
                nativeImage = new java.io.File(src);
            }
            else if (src.startsWith('~/')) {
                nativeImage = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, src.replace('~/', '')));
            }
            else if (src.startsWith('http')) {
                nativeImage = src;
            }
            else if (src.startsWith('res://')) {
                nativeImage = java.lang.Integer.valueOf(utils.ad.resources.getDrawableId(src.replace('res://', '')));
            }
        }
        return nativeImage;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        if (!this._builder)
            return value;
        this.resetImage(true);
        return value;
    };
    ImageCacheIt.getItem = function (src) {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.getItem(src, null, new com.github.triniwiz.imagecacheit.ImageCache.Callback({
                onSuccess: function (value) {
                    resolve(value);
                },
                onError: function (error) {
                    reject(error.getMessage());
                }
            }));
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
            resolve();
        });
    };
    ImageCacheIt.hasItem = function (src) {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.hasItem(src, new com.github.triniwiz.imagecacheit.ImageCache.Callback({
                onSuccess: function (value) {
                    resolve();
                },
                onError: function (error) {
                    reject(error.getMessage());
                }
            }));
        });
    };
    ImageCacheIt.clear = function () {
        com.github.triniwiz.imagecacheit.ImageCache.init(app.android.context);
        return new Promise(function (resolve, reject) {
            com.github.triniwiz.imagecacheit.ImageCache.clear();
            resolve();
        });
    };
    ImageCacheIt.prototype.setBorderAndRadius = function () {
        if (!this._builder)
            return null;
        var ColoredRoundedCornerBorders = com.github.triniwiz.imagecacheit.ColoredRoundedCornerBorders;
        var list = new java.util.ArrayList();
        if (this.hasUniformBorder() && this.hasBorderColor()) {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.ALL, this.style.borderTopColor ? this.style.borderTopColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderTopWidth), -1, -1));
        }
        else if (this.hasBorderColor()) {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_TOP, this.style.borderTopColor ? this.style.borderTopColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderTopWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_RIGHT, this.style.borderRightColor ? this.style.borderRightColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderRightWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_BOTTOM, this.style.borderBottomColor ? this.style.borderBottomColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderBottomWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_LEFT, this.style.borderLeftColor ? this.style.borderLeftColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderLeftWidth), -1, -1));
        }
        else {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopRightRadius), 0, ColoredRoundedCornerBorders.CornerType.TOP_RIGHT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BOTTOM_RIGHT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.BOTTOM_LEFT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.TOP_LEFT, 0, 0, -1, -1));
        }
        return list;
    };
    ImageCacheIt.prototype.setAspectResize = function () {
        var Target = com.bumptech.glide.request.target.Target;
        if (ImageCacheIt.isNumber(this.decodedWidth) && Number.isNaN(this.decodedHeight)) {
            this._builder.override(view_1.layout.toDevicePixels(this.decodedWidth), Target.SIZE_ORIGINAL);
        }
        if (ImageCacheIt.isNumber(this.decodedHeight) && Number.isNaN(this.decodedWidth)) {
            this._builder.override(Target.SIZE_ORIGINAL, view_1.layout.toDevicePixels(this.decodedHeight));
        }
        if (ImageCacheIt.isNumber(this.decodedHeight) && ImageCacheIt.isNumber(this.decodedWidth)) {
            this._builder.override(view_1.layout.toDevicePixels(this.decodedWidth), view_1.layout.toDevicePixels(this.decodedHeight));
        }
    };
    ImageCacheIt.prototype.resetImage = function (reload) {
        if (reload === void 0) { reload = false; }
        if (!this._builder)
            return;
        var transformations = new java.util.ArrayList();
        var MultiTransformation = com.bumptech.glide.load.MultiTransformation;
        switch (this.stretch) {
            case 'aspectFit':
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.FIT_CENTER);
                break;
            case 'aspectFill':
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.CENTER_CROP);
                break;
            case 'fill':
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.FIT_XY);
                break;
            case 'none':
            default:
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.MATRIX);
                break;
        }
        var getValue = function (value) {
            return value.substring(value.indexOf('(') + 1, value.indexOf(')'));
        };
        if (this.filter) {
            var filters = this.filter ? this.filter.split(' ') : [];
            filters.forEach(function (filter) {
                var value = getValue(filter);
                if (filter.indexOf('blur') > -1) {
                    var width = -1;
                    if (value.indexOf('%') === -1) {
                        value = view_1.Length.parse(value);
                        if (value.unit === 'px') {
                            width = value.value;
                        }
                        else if (value.unit === 'dip') {
                            width = view_1.layout.toDevicePixels(value.unit);
                        }
                        if (width > -1) {
                            transformations.add(new jp.wasabeef.glide.transformations.BlurTransformation(width));
                        }
                    }
                }
                else if (filter.indexOf('contrast') > -1) {
                    if (value.indexOf('%')) {
                        var contrast = parseFloat(value.replace('%', '')) / 100;
                        transformations.add(new jp.wasabeef.glide.transformations.gpu.ContrastFilterTransformation(new java.lang.Float(contrast).intValue()));
                    }
                }
                else if (filter.indexOf('brightness') > -1) {
                    if (value.indexOf('%')) {
                        var brightness = parseFloat(value.replace('%', '')) / 100;
                        if (brightness >= 0 && brightness < 1) {
                            brightness = -1 + brightness;
                        }
                        transformations.add(new jp.wasabeef.glide.transformations.gpu.BrightnessFilterTransformation(new java.lang.Float(brightness).intValue()));
                    }
                }
                else if (filter.indexOf('grayscale') > -1 || filter.indexOf('greyscale') > -1) {
                    transformations.add(new jp.wasabeef.glide.transformations.GrayscaleTransformation());
                }
                else if (filter.indexOf('invert') > -1) {
                    transformations.add(new jp.wasabeef.glide.transformations.gpu.InvertFilterTransformation());
                }
                else if (filter.indexOf('sepia') > -1) {
                    var sepia = parseFloat(value.replace('%', '')) / 100;
                    transformations.add(new jp.wasabeef.glide.transformations.gpu.SepiaFilterTransformation(new java.lang.Float(sepia).intValue()));
                }
            });
        }
        if (reload) {
            var image = ImageCacheIt.getImage(this.src);
            this._builder.load(image);
            this.setPlaceHolder();
            this.setErrorHolder();
        }
        var borderTransformations = this.setBorderAndRadius();
        if (borderTransformations.size() > 0) {
            var borderArray = borderTransformations.toArray();
            var borderArrayLength = borderArray.length;
            for (var i = 0; i < borderArrayLength; i++) {
                transformations.add(borderArray[i]);
            }
        }
        if (transformations.size() > 0) {
            var array = transformations.toArray();
            var count = array.length;
            var transformationArray = Array.create('com.bumptech.glide.load.Transformation', count);
            for (var i = 0; i < count; i++) {
                transformationArray[i] = array[i];
            }
            this._builder.apply(com.bumptech.glide.request.RequestOptions.bitmapTransform(new MultiTransformation(transformationArray)));
        }
        switch (this.transition) {
            case 'fade':
                var builder = new com.bumptech.glide.request.transition.DrawableCrossFadeFactory.Builder()
                    .setCrossFadeEnabled(true)
                    .build();
                this._builder.transition(com.bumptech.glide.load.resource.drawable.DrawableTransitionOptions.withCrossFade(builder));
                break;
            default:
                break;
        }
        this.setAspectResize();
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.android.js.map